@@ -1,4 +1,4 @@
-/* $Id: httpd.c,v 1.84 2006/01/08 10:08:32 ichiro Exp $ */
+/* $Id: httpd.c,v 1.90 2006/01/10 13:52:47 ichiro Exp $ */
 /*
  * Copyright (c) 2004, 2005, 2006
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -94,6 +94,7 @@ void httpd_proc(struct tparam *th2, int socket)
 	char uri_addr[URI_LEN];
 	char header[IRC_MAX];
 	char message[IRC_MAX];
+	char uid[AUTH_LEN];
 	char post_message[IRC_MAX * 2]; /* include url_encode mergin */
 	char *s, *q;
 	char cmd_cmd[CMD_LEN];
@@ -118,6 +119,7 @@ void httpd_proc(struct tparam *th2, int socket)
 	bzero(uri_addr, sizeof(uri_addr));
 	bzero(header, sizeof(header));
 	bzero(message, sizeof(message));
+	bzero(uid, sizeof(uid));
 	bzero(channel, sizeof(channel));
 	bzero(channel2, sizeof(channel2));
 	bzero(post_message, sizeof(post_message));
@@ -141,8 +143,8 @@ void httpd_proc(struct tparam *th2, int socket)
 	DPRINTF(1, ("meth_name= %s\n", meth_name));
 	DPRINTF(1, ("uri_addr= %s\n", uri_addr));
 	DPRINTF(1, ("http_ver= %s\n", http_ver));
-	DPRINTF(2, ("---------------------------\n"));
-	DPRINTF(2, ("BUF:%s\n", buf));
+	DPRINTF(2, ("------------------\n"));
+	DPRINTF(2, ("BUF:%s\n--------------\n", buf));
 
 	/* init header */
 	strcpy(header, http_header0);
@@ -154,6 +156,19 @@ void httpd_proc(struct tparam *th2, int socket)
 		 /* send data */
 		send_msg(socket, th2, header);
 		return;
+	} else if ((th2->auth_method == 0) || (th2->auth_method == 1)) {
+		strcpy(uid, find_uid(buf));
+		if (strstr(uid, "DOCOMO_PDC"))
+			th2->phone_carrier = DOCOMO_PDC;
+		else if (strstr(uid, "DOCOMO_FOMA"))
+			th2->phone_carrier = DOCOMO_FOMA;
+		else if (strstr(uid, "AU_EZWEB"))
+			th2->phone_carrier = AU_EZWEB;
+		else if (strstr(uid, "UNKNOWN"))
+			th2->phone_carrier = OTHER;
+
+		DPRINTF(1, ("get carrier type: %d %s\n",
+			th2->phone_carrier, uid));
 	}
 
 	/* check timeout */
@@ -245,11 +260,17 @@ post_start:
 
 		/* if cannot read 'm=' or 'cname=', read more */
 		if((!strstr(buf, "m=")) && (!strstr(buf, "cname="))) {
-			/* zero clear buffer */
-			bzero(buf, sizeof(buf));
-			read(socket, buf, post_length);
+			/* zero clear */
+			bzero(post_message, sizeof(post_message));
 
-			DPRINTF(0, ("POST data: %s\n", buf));
+			/* read more */
+			read(socket, post_message, post_length);
+			strcat(buf, post_message);
+
+			/* zero clear */
+			bzero(post_message, sizeof(post_message));
+
+			DPRINTF(0, ("POST data: %s\n----\n", buf));
 		}
 
 		/* Get post message */
@@ -265,7 +286,7 @@ post_start:
 			}
 
 			/* URL decord */
-			url_decode_jis(post_message);
+			url_decode_jis(post_message, th2->phone_carrier);
 			DPRINTF(2, ("post msg decode: %s\n", post_message));
 
 			/* Get channel number to post */
@@ -344,13 +365,13 @@ post_start:
 			/* make command message */
 			if (strcmp(cmd_cmd, "join") == 0) {
 			   if(strlen(channel) > 0){
-				url_decode_jis(channel);
+				url_decode_jis(channel, th2->phone_carrier);
 				/* send join */
 				send_join(th2, channel);
 			   }
 			} else if (strcmp(cmd_cmd, "part") == 0) {
 			   if(strlen(channel) > 0){
-				url_decode_jis(channel);
+				url_decode_jis(channel, th2->phone_carrier);
 				/* send part */
 				send_part(th2, channel);
 			   }
@@ -363,10 +384,10 @@ post_start:
 			   if((strlen(channel) > 0) &&
 				(strlen(cmd_buf) > 0)){
 				/* any -> #hoge*.jp */
-				url_decode_jis(channel);
+				url_decode_jis(channel,th2->phone_carrier);
 				channel_decode(channel2, channel);
 				/* decode */
-				url_decode_jis(cmd_buf);
+				url_decode_jis(cmd_buf, th2->phone_carrier);
 				sprintf(th2->postdata, ":%s TOPIC %s :%s\r\n",
 					th2->real_nickname,
 					channel2, cmd_buf);
@@ -440,21 +461,23 @@ index_start:
 				strcat(subtopic, "\0");
 			}
 		   }
-			if (n < 9) {
-			    sprintf(message,
-			    "%d <a accesskey=\"%d\" href=\"subuser%d\">%s</a> "
-			    "[%d] <a href=\"subtopic%d\">%s</a><br>",
-			    n, n, n, th2->name[n], th2->member_count[n],
-			    n, subtopic);
-			} else {
-			    sprintf(message,
-			    "* <a href=\"subuser%d\">%s</a> "
-			    "[%d] <a href=\"subtopic%d\">%s</a><br>",
-			    n, th2->name[n], th2->member_count[n],
-			    n, subtopic);
-			}           
-			send_buf(th2, message);
-
+			if (th2->name[n][0] == '#' || th2->name[n][0] == '%') {
+			    if (n < 9) {
+				sprintf(message,
+				"%d <a accesskey=\"%d\" href=\"subuser%d\">%s</a> "
+				"[%d] <a href=\"subtopic%d\">%s</a><br>",
+				n, n, n, th2->name[n], th2->member_count[n],
+				n, subtopic);
+			    } else {
+				sprintf(message,
+				"* <a href=\"subuser%d\">%s</a> "
+				"[%d] <a href=\"subtopic%d\">%s</a><br>",
+				n, th2->name[n], th2->member_count[n],
+				n, subtopic);
+			    }           
+			    send_buf(th2, message);
+			}
+			/* clear buf */
 			strcpy(subtopic, "\0");
 		}
 
@@ -592,7 +615,7 @@ command_start:
 		send_buf(th2, message);
 
 		sprintf(message,
-		    "<br><left>kircd Ver %s </left>", VERSION);
+		    "<br>kircd Ver %s", VERSION);
 		send_buf(th2, message);
 
 		send_msg(socket, th2, header);
