@@ -1,4 +1,4 @@
-/* $Id: kircd.h,v 1.50 2006/01/08 07:29:35 ichiro Exp $ */
+/* $Id: kircd.h,v 1.58 2006/01/09 19:08:07 ichiro Exp $ */
 /* #define DEBUG */
 /*
  * Copyright (c) 2004, 2005, 2006
@@ -84,11 +84,21 @@
 #define NAME_LEN 10
 
 /* rfc1459, max length of IRC message is 512 byte */
-#define IRC_MAX 600
+#define IRC_MAX 1000
 
 /* subtopic length */
 #define SUBTOPIC_LEN 20
 
+/* emoji */
+#define DAT_ROW 699
+#define DAT_COL 5
+
+#define DAT_NUM 0
+#define D_KEY   1
+#define AU_KEY  2
+#define D_STR   3
+#define AU_STR  4
+
 /* CTCP */
 static char ctcp_clientinfo[] = {
         "CLIENTINFO VERSION\r\n"
@@ -136,6 +146,13 @@ struct tparam {
 	char user_agent[IRC_MAX * 2];
 	char store_message[SBUFLEN];
 
+	/* carrier */
+	int  phone_carrier;
+#define DOCOMO_PDC	0x0001
+#define DOCOMO_FOMA	0x0002
+#define AU_EZWEB	0x0003
+#define OTHER		0x0004
+
 	/* send buffer */
 	char *send_buf;
 	int  send_buflen;
@@ -166,6 +183,11 @@ struct config {
 	time_t timeout;
 };
 
+/* emoji data */
+const int emoji[DAT_ROW][DAT_COL];
+extern int emoji_encode(unsigned char *, int);
+extern int emoji_decode(unsigned char *, int);
+
 int main(int ac, char *av[]);
 int get_addr(struct addrinfo, const char*, const char*, int);
 void init(int, struct config *);
@@ -193,9 +215,8 @@ extern int nick_recv(struct tparam *);
 extern int send_join(struct tparam *, char *);
 extern int send_part(struct tparam *, char *);
 
-extern int url_decode_jis(char *);
+extern int url_decode_jis(char *, int);
 extern int decode_jis2cp932(char *);
-extern int url_decode_rawdata(char *, char *);
 
 extern int charconv(char *, size_t, const char *, size_t, const char *, const char *);
 extern int channel_encode(char *, char *);
@@ -205,3 +226,5 @@ extern char * base64_decode(char *);
 extern char * href_conv(char *);
 extern int strcmp2(char *, char *);
 extern int count_user(char *);
+
+extern char* find_uid(char *);
